views

package
v0.0.0-...-4a6608b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 1, 2026 License: AGPL-3.0 Imports: 13 Imported by: 0

Documentation

Overview

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

Index

Constants

const APP_NAME = "PIXELFOX.cc"

Variables

This section is empty.

Functions

func APIPage

func APIPage() templ.Component

func AboutPage

func AboutPage() templ.Component

func ContactPage

func ContactPage() templ.Component

func Features

func Features(fromProtected bool) templ.Component

func FilePicker

func FilePicker() templ.Component

func Home

func Home(
	page string,
	fromProtected bool,
	isError bool,
	msg fiber.Map,
	cmp templ.Component,
	isAdmin bool,
	ogViewModel *viewmodel.OpenGraph,
) templ.Component

func HomeCtx

func HomeCtx(
	c *fiber.Ctx,
	page string,
	fromProtected bool,
	isError bool,
	msg fiber.Map,
	cmp templ.Component,
	isAdmin bool,
	ogViewModel *viewmodel.OpenGraph,
) templ.Component

func HomeIndex

func HomeIndex(fromProtected bool, csrfToken string, plan string, stats statistics.StatisticsData) templ.Component

func ImageContent

func ImageContent(model viewmodel.Image) templ.Component

ImageContent ist der gesamte Bildbereich mit allen Links und Optionen Diese Funktion wird von HTMX durch Polling aktualisiert, wenn sie am Anfang im Lade-Zustand ist

func ImageOptions

func ImageOptions(model viewmodel.Image) templ.Component

ImageOptions zeigt die Link-Optionen und Download-Buttons unter dem Bild

func ImageViewer

func ImageViewer(model viewmodel.Image) templ.Component

func ImageViewerWithUser

func ImageViewerWithUser(model viewmodel.Image, currentUserID uint, imageOwnerID uint) templ.Component

func Layout

func Layout(layout viewmodel.Layout) templ.Component

func NewsContent

func NewsContent(newsList []models.News) templ.Component

func NewsShowContent

func NewsShowContent(news models.News) templ.Component

func PageDisplay

func PageDisplay(page models.Page) templ.Component

func PricingPage

func PricingPage() templ.Component

func ProcessedImageElement

func ProcessedImageElement(model viewmodel.Image) templ.Component

ProcessedImageElement zeigt das verarbeitete Bild an

func Stats

func TrustBadges

func TrustBadges() templ.Component

Types

This section is empty.

Directories

Path Synopsis
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943

Jump to