admin_views

package
v0.0.0-...-4a6608b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 1, 2026 License: AGPL-3.0 Imports: 11 Imported by: 0

Documentation

Overview

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

templ: version: v0.3.943

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AdminLayout

func AdminLayout(content templ.Component) templ.Component

func AdminReportShow

func AdminReportShow(report *models.ImageReport, csrfToken string) templ.Component

func AdminReportsPage

func AdminReportsPage(openReports []models.ImageReport, recentClosed []models.ImageReport) templ.Component

func Dashboard

func Dashboard(totalUsers int, totalImages int, totalAlbums int, openReports int, recentUsers []models.User, imageStats []models.DailyStats, userStats []models.DailyStats) templ.Component

func ImageEdit

func ImageEdit(image models.Image) templ.Component

func ImageManagement

func ImageManagement(images []models.Image, currentPage int, totalPages int, csrfToken string) templ.Component

func NewsCreate

func NewsCreate() templ.Component

func NewsEdit

func NewsEdit(news models.News) templ.Component

func NewsManagement

func NewsManagement(newsList []models.News) templ.Component

func PageEdit

func PageEdit(page models.Page, isEdit bool, csrfToken string) templ.Component

func PageManagement

func PageManagement(pages []models.Page, csrfToken string) templ.Component

func QueueItemView

func QueueItemView(item QueueItem) templ.Component

QueueItem is the template for a single queue item in the list

func QueueItems

func QueueItems(items []QueueItem, currentTime time.Time) templ.Component

QueueItems is the template for the items table that will be refreshed via HTMX

func QueueItemsTable

func QueueItemsTable(items []QueueItem, currentTime time.Time) templ.Component

QueueItemsTable ist der Teil, der per HTMX aktualisiert wird

func Settings

func Settings(settings models.AppSettings, csrfToken string) templ.Component

func StorageManagement

func StorageManagement(data struct {
	PoolStats            []models.StoragePoolStats
	HealthStatus         map[uint]bool
	Pools                []models.StoragePool
	Snapshots            map[uint]repository.HealthSnapshot
	TotalUsedSize        int64
	TotalMaxSize         int64
	TotalUsagePercentage float64
	TotalImageCount      int64
	TotalVariantCount    int64
	TotalPoolsCount      int
	HealthyPoolsCount    int
}) templ.Component

func StoragePoolForm

func StoragePoolForm(pool models.StoragePool, isEdit bool, csrfToken string) templ.Component

func StoragePoolMoveForm

func StoragePoolMoveForm(source models.StoragePool, pools []models.StoragePool, csrfToken string) templ.Component

func UserEdit

func UserEdit(user models.User, plan string) templ.Component

func UserManagement

func UserManagement(usersWithStats []UserWithStats, currentPage int, pages []int) templ.Component

Types

type QueueItem

type QueueItem struct {
	Key       string
	Value     string
	Type      string
	TTL       time.Duration
	Size      int64
	CreatedAt time.Time
}

QueueItem struct für die Anzeige

type UserWithStats

type UserWithStats struct {
	User         models.User
	ImageCount   int64
	AlbumCount   int64
	StorageUsage int64
}

Jump to