Documentation
¶
Overview ¶
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
Index ¶
- Constants
- func APIPage() templ.Component
- func AboutPage() templ.Component
- func ContactPage() templ.Component
- func Features(fromProtected bool) templ.Component
- func FilePicker() templ.Component
- func Home(page string, fromProtected bool, isError bool, msg fiber.Map, ...) templ.Component
- func HomeCtx(c *fiber.Ctx, page string, fromProtected bool, isError bool, msg fiber.Map, ...) templ.Component
- func HomeIndex(fromProtected bool, csrfToken string, plan string, ...) templ.Component
- func ImageContent(model viewmodel.Image) templ.Component
- func ImageOptions(model viewmodel.Image) templ.Component
- func ImageViewer(model viewmodel.Image) templ.Component
- func ImageViewerWithUser(model viewmodel.Image, currentUserID uint, imageOwnerID uint) templ.Component
- func Layout(layout viewmodel.Layout) templ.Component
- func NewsContent(newsList []models.News) templ.Component
- func NewsShowContent(news models.News) templ.Component
- func PageDisplay(page models.Page) templ.Component
- func PricingPage() templ.Component
- func ProcessedImageElement(model viewmodel.Image) templ.Component
- func Stats(stats statistics.StatisticsData) templ.Component
- func TrustBadges() templ.Component
Constants ¶
const APP_NAME = "PIXELFOX.cc"
Variables ¶
This section is empty.
Functions ¶
func ContactPage ¶
func FilePicker ¶
func HomeIndex ¶
func HomeIndex(fromProtected bool, csrfToken string, plan string, stats statistics.StatisticsData) templ.Component
func ImageContent ¶
ImageContent ist der gesamte Bildbereich mit allen Links und Optionen Diese Funktion wird von HTMX durch Polling aktualisiert, wenn sie am Anfang im Lade-Zustand ist
func ImageOptions ¶
ImageOptions zeigt die Link-Optionen und Download-Buttons unter dem Bild
func ImageViewerWithUser ¶
func PricingPage ¶
func ProcessedImageElement ¶
ProcessedImageElement zeigt das verarbeitete Bild an
func Stats ¶
func Stats(stats statistics.StatisticsData) templ.Component
func TrustBadges ¶
Types ¶
This section is empty.
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
templ: version: v0.3.943
|
templ: version: v0.3.943 |
|
templ: version: v0.3.943
|
templ: version: v0.3.943 |
|
templ: version: v0.3.943
|
templ: version: v0.3.943 |
|
templ: version: v0.3.943
|
templ: version: v0.3.943 |
|
templ: version: v0.3.943
|
templ: version: v0.3.943 |
|
templ: version: v0.3.943
|
templ: version: v0.3.943 |
|
templ: version: v0.3.943
|
templ: version: v0.3.943 |
|
templ: version: v0.3.943
|
templ: version: v0.3.943 |
|
templ: version: v0.3.943
|
templ: version: v0.3.943 |
Click to show internal directories.
Click to hide internal directories.