Documentation
¶
Overview ¶
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
templ: version: v0.3.943
Index ¶
- func AdminLayout(content templ.Component) templ.Component
- func AdminReportShow(report *models.ImageReport, csrfToken string) templ.Component
- func AdminReportsPage(openReports []models.ImageReport, recentClosed []models.ImageReport) templ.Component
- func Dashboard(totalUsers int, totalImages int, totalAlbums int, openReports int, ...) templ.Component
- func ImageEdit(image models.Image) templ.Component
- func ImageManagement(images []models.Image, currentPage int, totalPages int, csrfToken string) templ.Component
- func NewsCreate() templ.Component
- func NewsEdit(news models.News) templ.Component
- func NewsManagement(newsList []models.News) templ.Component
- func PageEdit(page models.Page, isEdit bool, csrfToken string) templ.Component
- func PageManagement(pages []models.Page, csrfToken string) templ.Component
- func QueueItemView(item QueueItem) templ.Component
- func QueueItems(items []QueueItem, currentTime time.Time) templ.Component
- func QueueItemsTable(items []QueueItem, currentTime time.Time) templ.Component
- func Settings(settings models.AppSettings, csrfToken string) templ.Component
- func StorageManagement(data struct{ ... }) templ.Component
- func StoragePoolForm(pool models.StoragePool, isEdit bool, csrfToken string) templ.Component
- func StoragePoolMoveForm(source models.StoragePool, pools []models.StoragePool, csrfToken string) templ.Component
- func UserEdit(user models.User, plan string) templ.Component
- func UserManagement(usersWithStats []UserWithStats, currentPage int, pages []int) templ.Component
- type QueueItem
- type UserWithStats
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AdminReportShow ¶
func AdminReportShow(report *models.ImageReport, csrfToken string) templ.Component
func AdminReportsPage ¶
func AdminReportsPage(openReports []models.ImageReport, recentClosed []models.ImageReport) templ.Component
func ImageManagement ¶
func NewsCreate ¶
func QueueItemView ¶
QueueItem is the template for a single queue item in the list
func QueueItems ¶
QueueItems is the template for the items table that will be refreshed via HTMX
func QueueItemsTable ¶
QueueItemsTable ist der Teil, der per HTMX aktualisiert wird
func StorageManagement ¶
func StorageManagement(data struct {
PoolStats []models.StoragePoolStats
HealthStatus map[uint]bool
Pools []models.StoragePool
Snapshots map[uint]repository.HealthSnapshot
TotalUsedSize int64
TotalMaxSize int64
TotalUsagePercentage float64
TotalImageCount int64
TotalVariantCount int64
TotalPoolsCount int
HealthyPoolsCount int
}) templ.Component
func StoragePoolForm ¶
func StoragePoolMoveForm ¶
func StoragePoolMoveForm(source models.StoragePool, pools []models.StoragePool, csrfToken string) templ.Component
func UserManagement ¶
func UserManagement(usersWithStats []UserWithStats, currentPage int, pages []int) templ.Component
Types ¶
Source Files
¶
- admin_layout_templ.go
- dashboard_templ.go
- image_edit_templ.go
- image_management_templ.go
- news_edit_templ.go
- news_management_templ.go
- page_edit_templ.go
- page_management_templ.go
- queue_dashboard_templ.go
- reports_templ.go
- settings_templ.go
- storage_management_templ.go
- storage_pool_form_templ.go
- storage_pool_move_templ.go
- user_edit_templ.go
- user_management_templ.go
Click to show internal directories.
Click to hide internal directories.